package Bundle::Locale::CLDR::Centralamerica;

use version;

our $VERSION = version->declare('v0.34.1');

=head1 NAME Bundle::Locale::CLDR::Centralamerica

=head1 CONTENTS

Locale::CLDR::Locales::Es 0.34.1
Locale::CLDR::Locales::En::Any 0.34.1
Locale::CLDR::Locales::Es::Any 0.34.1
Locale::CLDR::Locales::En::Any::Bz 0.34.1
Locale::CLDR::Locales::Es::Any::Bz 0.34.1
Locale::CLDR::Locales::Es::Any::Cr 0.34.1
Locale::CLDR::Locales::Es::Any::Gt 0.34.1
Locale::CLDR::Locales::Es::Any::Hn 0.34.1
Locale::CLDR::Locales::Es::Any::Mx 0.34.1
Locale::CLDR::Locales::Es::Any::Ni 0.34.1
Locale::CLDR::Locales::Es::Any::Pa 0.34.1
Locale::CLDR::Locales::Es::Any::Sv 0.34.1
Locale::CLDR::Locales::En::Any::001 0.34.1
Locale::CLDR::Locales::Es::Any::419 0.34.1

=cut

1;

